ignored_html_tags = {
    "article",
    "aside",
    "figure",
    "footer",
    "frameset",
    "frame",  # TODO choper le contenu
    "header",
    "iframe",  # TODO choper le contenu
    "label",
    "main",
    "noframe",
    "noscript",
    "section",
    "show",
    "tbody",
    "time",
    "tt",
}
